@@ -16,8 +16,8 @@
 #
 
 def benchmark( label, times, &block )
-  begtime = Time.times.utime
+  begtime = Process.times.utime
   times.times( &block )
-  endtime = Time.times.utime
-  puts "#{label}: #{endtime - begtime} sec"
+  endtime = Process.times.utime
+  $stderr.printf "%-10s: %f sec\n", label, endtime - begtime
 end
