@@ -24,8 +24,6 @@ require 'amstd/to_s'
 require 'amstd/must'
 
 
-class ImplementationError < StandardError ; end
-
 class Module
 
   def abstract( name )
@@ -33,7 +31,7 @@ class Module
 
     module_eval %-
       def #{mname}( *args, &blk )
-        raise ImplementationError, "abstract method '#{mname}' called"
+        raise NotImplementedError, "abstract method '#{mname}' called"
       end
     -
   end
