@@ -1,7 +1,7 @@
 #
 # recycle.rb
 #
-#   Copyright (c) 1999,2000 Minero Aoki <aamine@dp.u-netsurf.ne.jp>
+#   Copyright (c) 1999-2001 Minero Aoki <aamine@dp.u-netsurf.ne.jp>
 #
 #   This program is free software.
 #   You can distribute/modify this program under the terms of
@@ -14,16 +14,15 @@ module Recyclable
   BEGIN_GC_SIZE = 5
 
 
-  def Recyclable.append_features( mod )
+  def self.append_features( mod )
     super
-    class << mod
 
-    module_eval %-
+    mod.module_eval %-
       @spare = []
       @begin_gc = 5
     -
 
-    def new( *args, &block )
+    def mod.new( *args, &block )
       gavage_collect
 
       unless @spare.empty? then
@@ -36,26 +35,24 @@ module Recyclable
       obj
     end
 
-    def use_instance( *args )
+    def mod.use_instance( *args )
       obj = new( *args )
       yield obj
       obj.type.finished obj
     end
 
-    def finished( obj )
+    def mod.finished( obj )
       @spare.push obj
       gavage_collect
     end
 
     private
 
-    def gavage_collect
+    def mod.gavage_collect
       if @spare.size > @begin_gc then
         @spare = @spare[ 0, @spare.size / 2 ]
       end
     end
-
-    end   # class << mod
   end
 
 end
