@@ -19,6 +19,10 @@ unless defined? ParseError then
   ParseError = Racc::ParseError
 end
 
+unless defined? NotImplementedError then
+  NotImplementedError = NotImplementError
+end
+
 
 module Racc
 
@@ -42,7 +46,7 @@ module Racc
       Racc_YY_Parse_Method      = :_racc_yyparse_rb
     end
 
-    Racc_ruby_parser_version = '1.3.7'
+    Racc_ruby_parser_version = '1.3.9'
     Racc_parser_version = Racc_ruby_parser_version
 
     def self.racc_runtime_type
@@ -98,14 +102,14 @@ module Racc
     end
 
     def next_token
-      raise NotImplementError, "#{self.type}\#next_token must be defined"
+      raise NotImplementedError, "#{self.type}\#next_token is not defined"
     end
 
     def _racc_do_parse_rb( arg, in_debug )
       action_table, action_check, action_default, action_pointer,
       goto_table,   goto_check,   goto_default,   goto_pointer,
       nt_base,      reduce_table, token_table,    shift_n,
-      reduce_n,     use_result    = arg
+      reduce_n,     use_result,   * = arg
 
       _racc_init_sysvars
       tok = act = i = nil
@@ -159,7 +163,7 @@ module Racc
       action_table, action_check, action_default, action_pointer,
       goto_table,   goto_check,   goto_default,   goto_pointer,
       nt_base,      reduce_table, token_table,    shift_n,
-      reduce_n,     use_result,   = arg
+      reduce_n,     use_result,   * = arg
 
       _racc_init_sysvars
       tok = nil
@@ -226,7 +230,7 @@ module Racc
       action_table, action_check, action_default, action_pointer,
       goto_table,   goto_check,   goto_default,   goto_pointer,
       nt_base,      reduce_table, token_table,    shift_n,
-      reduce_n,     use_result,   = arg
+      reduce_n,     use_result,   * = arg
 nerr = 0   # tmp
 
       if act > 0 and act < shift_n then
@@ -330,7 +334,7 @@ nerr = 0   # tmp
       action_table, action_check, action_default, action_pointer,
       goto_table,   goto_check,   goto_default,   goto_pointer,
       nt_base,      reduce_table, token_table,    shift_n,
-      reduce_n,     use_result,   = arg
+      reduce_n,     use_result,   * = arg
       state = @racc_state
       vstack = @racc_vstack
       tstack = @racc_tstack
