@@ -13,50 +13,35 @@ module TMail
 
   class Scanner_R
 
-    Version = '0.9.1'
+    Version = '0.9.4'
     Version.freeze
 
+    #
+    # regexps
+    #
 
-    def initialize( str, header, comments )
-      @s = StringScanner.new( str, false )
+    atomchar  = Regexp.quote( "\#!$%&`'*+{|}~^/=?" ) + '\\-'
+    tokenchar = Regexp.quote( "\#!$%&`'*+{|}~^." )   + '\\-'
+    jisstr    = '|\e..[^\e]*\e..'
 
-      @header = header
-      @comments = comments
-
-      @atom_mode = :atom
-      @word_re = ATOM
-      @recv_mode = false
-
-      case header
-      when 'CTypeH', 'CEncodingH', 'CDispositionH'
-        @atom_mode = :token
-        @word_re = TOKEN
-      when 'RecvH'
-        @recv_mode = true
-      end
-
-      @debug = false
+    ATOM = {}
+    TOKEN = {}
+    {
+      'e' => '|(?:[\xa1-\xfe][\xa1-\xfe])+',
+      's' => '|(?:[\x81-\x9f\xe0-\xef][\x40-\x7e\x80-\xfc])+',
+      'u' => '|(?:[\xc0-\xdf][\x80-\xbf]|[\xe0-\xef][\x80-\xbf][\x80-\xbf])+',
+      'n' => ''
+    }.each do |k,v|
+      ATOM[k]  = /\A[\w#{atomchar}]+#{v}#{jisstr}/n
+      TOKEN[k] = /\A[\w#{tokenchar}]+#{v}#{jisstr}/n
     end
 
-    attr_accessor :debug
-
-
-    # regexps
-
-    atomchars  = Regexp.quote( "\#!$%&`'*+{|}~^/=?" ) + '\\-'
-    tokenchars = Regexp.quote( "\#!$%&`'*+{|}~^." )   + '\\-'
-    eucchars   = "\xa1\xa1-\xf3\xfe"
-    jisstr     = '\\e..[^\\e]*\\e..'
-
-    ATOM    = /\A[\w#{atomchars}#{eucchars}]+|#{jisstr}/
-    TOKEN   = /\A[\w#{tokenchars}#{eucchars}]+|#{jisstr}/
+    LWSP    = /\A[\n\r\t ]+/n
     DIGIT   = /\A\d+\z/
 
-    LWSP    = /\A[\n\r\t ]+/
-
-    QSTR   = /\A[^"\\\e]+|#{jisstr}/
-    CSTR   = /\A[^\)\(\\\e]+|#{jisstr}/
-    DSTR   = /\A[^\]\\]+|#{jisstr}/
+    QSTR   = /\A[^"\\\e]+#{jisstr}/n
+    CSTR   = /\A[^\)\(\\\e]+#{jisstr}/n
+    DSTR   = /\A[^\]\\]+#{jisstr}/n
 
 
     RECV_TOKEN = {
@@ -69,6 +54,30 @@ module TMail
     }
 
 
+    def initialize( str, header, comments )
+      @s = StringScanner.new( str, false )
+
+      @header = header
+      @comments = comments
+
+      @atom_mode = :atom
+      @word_re = ATOM[ $KCODE[0,1].downcase ]
+      @recv_mode = false
+
+      case header
+      when 'CTypeH', 'CEncodingH', 'CDispositionH'
+        @atom_mode = :token
+        @word_re = TOKEN[ $KCODE[0,1].downcase ]
+      when 'RecvH'
+        @recv_mode = true
+      end
+
+      @debug = false
+    end
+
+    attr_accessor :debug
+
+
     def scan( &block )
       if @debug then
         scan_main do |arr|
@@ -140,9 +149,7 @@ module TMail
     def scan_qstr( exp, term, type )
       ret = ''
       while true do
-        if @s.empty? then
-          scan_error! "found unterminated #{type}"
-        end
+        @s.empty? and scan_error! "found unterminated #{type}"
         
         if    tmp = @s.scan( exp ) then ret << tmp
         elsif @s.skip( term )      then break
@@ -161,9 +168,7 @@ module TMail
       nest = 1
 
       while nest > 0 do
-        if @s.empty? then
-          scan_error! 'found unterminated comment'
-        end
+        @s.empty? and scan_error! 'found unterminated comment'
 
         if    tmp = @s.scan(CSTR) then ret << tmp
         elsif @s.skip( /\A\)/ )   then nest -= 1; ret << ')' unless nest == 0
@@ -178,7 +183,7 @@ module TMail
     end
 
 
-    def scan_error( msg )
+    def scan_error!( msg )
       raise ScanError, msg
     end
 
